DROP TYPE filial_type FORCE;
DROP TYPE telefone_type FORCE;
DROP TYPE funcionario_type FORCE;
DROP TYPE motorista_type FORCE;
DROP TYPE auxiliar_type FORCE;
DROP TYPE caminhao_type FORCE;
DROP TYPE cliente_type FORCE;
DROP TYPE carregar_type FORCE;
DROP TYPE carga_type FORCE;
DROP TYPE contrato_type FORCE;
DROP TYPE contrata_type FORCE;
DROP TYPE registro_type FORCE;
DROP TYPE motoristaCaminhao_type FORCE;
DROP TYPE cartao_type FORCE;
DROP TYPE dirige_type FORCE;
DROP TYPE telefones_nt FORCE;
DROP TYPE tel_num FORCE;

DROP TABLE	registro_table;
DROP TABLE	motoristaCaminhao_table;
DROP TABLE	Cartao_table;
DROP TABLE	Contrata_table;
DROP TABLE	Carregar_table;
DROP TABLE	Carga_table;
DROP TABLE	Dirige_table;
DROP TABLE	Contrato_table;
DROP TABLE	Cliente_table;
DROP TABLE	Caminhao_table;
DROP TABLE	Auxiliar_table;
DROP TABLE	Motorista_table;
DROP TABLE	Funcionario_table;
DROP TABLE	Filial_table;

CREATE OR REPLACE TYPE filial_type AS OBJECT(
	codigo NUMBER,
	nome VARCHAR2(30),
	CEP character(9),
	Complemento varchar2(30)
)
/

CREATE TABLE filial_table OF filial_type(
	codigo PRIMARY KEY,
	nome NOT NULL
)
;



CREATE OR REPLACE TYPE telefone_type as OBJECT(
	codigo_area character(3),
	numero  varchar(10) 
)
/

CREATE OR REPLACE TYPE tel_num AS VARRAY(4) OF telefone_type;
/

CREATE TYPE telefones_nt AS TABLE OF tel_num;
/

CREATE OR REPLACE TYPE funcionario_type as OBJECT(
	filial REF filial_type,
	CPF character(14), 
	supervisor REF funcionario_type,
	salario NUMBER,
	data_Nascimento DATE,
	Nome VARCHAR2(30),
	Telefones telefones_nt
) NOT FINAL;
/

ALTER TYPE filial_type
	ADD ATTRIBUTE (chefe REF funcionario_type) CASCADE;

CREATE TABLE funcionario_table of funcionario_type(
	cpf primary key,
	filial NOT NULL WITH ROWID REFERENCES filial_table
)
NESTED TABLE telefones STORE AS lista_fones;

CREATE OR REPLACE TYPE Motorista_type UNDER funcionario_type (
	habilitacao character(1)
)
/

CREATE TABLE Motorista_table of Motorista_type(
	cpf primary key, 
	habilitacao NOT NULL
)
NESTED TABLE telefones STORE AS lista_fones_mot;

CREATE OR REPLACE TYPE auxiliar_type UNDER funcionario_type (
	Escolaridade VARCHAR2(30)
)
/

CREATE TABLE auxiliar_table of auxiliar_type(
	cpf primary key,
	escolaridade NOT NULL
)
NESTED TABLE telefones STORE AS lista_fones_aux;

CREATE OR REPLACE TYPE Caminhao_type as OBJECT(
	filial REF filial_type,
	Placa character(8),
	quilometragem FLOAT
)
/

CREATE TABLE Caminhao_table of Caminhao_type(
	filial NOT NULL WITH ROWID REFERENCES filial_table,
	Placa primary key
);

CREATE OR REPLACE TYPE Cliente_type as OBJECT (
	nome varchar2(30),
	CNPJ character(18), 
    CEP character(9), 
    complemento varchar2(30), 
	telefones telefones_nt
)
/


CREATE TABLE Cliente_table of Cliente_type(
	CNPJ primary key,
	CEP NOT NULL, 
	complemento NOT NULL
)NESTED TABLE telefones STORE AS lista_fones_cli;


CREATE OR REPLACE TYPE Contrato_type as OBJECT(
    codigo NUMBER
	)
/

CREATE TABLE Contrato_table of Contrato_type(
	codigo primary key
)
/

CREATE OR REPLACE TYPE Dirige_type as OBJECT(
    motorista REF motorista_type,
    caminhao ref caminhao_type,
    Data_inicio Date,
    Data_fim Date
)
/

CREATE TABLE dirige_table OF dirige_type(
	motorista NOT NULL WITH ROWID REFERENCES motorista_table,
	caminhao NOT NULL WITH ROWID REFERENCES caminhao_table
)
;

CREATE OR REPLACE TYPE Carga_type as OBJECT(
  codigo NUMBER,
  cliente REF cliente_type,
  contrato REF contrato_type,
  tipo varchar2(30),
  peso FLOAT,
  tamanho FLOAT,
  CEPdestino character(9),
  complementoDestino varchar2(30)
)
/

 CREATE TABLE carga_table OF carga_type(
	cliente NOT NULL WITH ROWID REFERENCES cliente_table,
	contrato NOT NULL WITH ROWID REFERENCES contrato_table, 
	tipo NOT NULL
)
;

 CREATE OR REPLACE TYPE Carregar_type as OBJECT(
   carga REF carga_type,
   cliente REF cliente_type,
   caminhao REF caminhao_type,
   auxiliar REF auxiliar_type,
   contrato REF contrato_type
)
/

 CREATE TABLE carregar_table OF carregar_type(
	carga NOT NULL WITH ROWID REFERENCES carga_table,
	caminhao NOT NULL WITH ROWID REFERENCES caminhao_table,
	cliente NOT NULL WITH ROWID REFERENCES cliente_table,
	contrato NOT NULL WITH ROWID REFERENCES contrato_table
)
;


CREATE OR REPLACE TYPE Contrata_type as OBJECT(
   cliente REF cliente_type,
   contrato REF contrato_type,
   filial REF filial_type,
   data_contrata date
 )
 /

 CREATE TABLE contrata_table OF contrata_type(
	filial NOT NULL WITH ROWID REFERENCES filial_table,
	contrato NOT NULL WITH ROWID REFERENCES contrato_table,
	cliente NOT NULL WITH ROWID REFERENCES cliente_table
)
;

CREATE OR REPLACE TYPE Cartao_type as OBJECT(
    Numero character(19),
    filial REF filial_type
)
/

CREATE TABLE cartao_table OF cartao_type(
	numero PRIMARY KEY,
	filial NOT NULL WITH ROWID REFERENCES filial_table
)
;

CREATE OR REPLACE TYPE MotoristaCaminhao_type as OBJECT(
    cartao REF cartao_type,
    motorista REF motorista_type,
    caminhao REF caminhao_type
)
/

CREATE TABLE motoristaCaminhao_table OF motoristaCaminhao_type(
	cartao NOT NULL WITH ROWID REFERENCES cartao_table,
	motorista NOT NULL WITH ROWID REFERENCES motorista_table,
	caminhao NOT NULL WITH ROWID REFERENCES caminhao_table
)
;

CREATE OR REPLACE TYPE Registro_type as OBJECT(
    data_registro DATE,
    filial REF filial_type,
    valor FLOAT
)
/

CREATE TABLE registro_table OF registro_type(
	data_registro PRIMARY KEY,
	filial NOT NULL WITH ROWID REFERENCES filial_table
)
;
